Changes
=======

Unreleased
----------

Version 0.5.4
-------------

Released 2024-08-03

- Add Python 3.12 to CI. `#166 <https://github.com/dajiaji/pyseto/pull/166>`__
- Update dependencies.
    - Bump cryptography to 43.0.0. `#195 <https://github.com/dajiaji/pyhpke/pull/195>`__
- Update dev dependencies.
    - Bump codecov/codecov-action to v4. `#199 <https://github.com/dajiaji/pyseto/pull/199>`__
    - Bump pytest to 8.3.2. `#198 <https://github.com/dajiaji/pyhpke/pull/198>`__
    - Bump pre-commit/mirrors-mypy to 1.11.0. `#197 <https://github.com/dajiaji/pyseto/pull/197>`__
    - Bump tox to 4.16.0. `#194 <https://github.com/dajiaji/pyseto/pull/194>`__
    - Bump sphinx-autodoc-typehints to 2.0.1. `#186 <https://github.com/dajiaji/pyseto/pull/186>`__
    - Bump pre-commit/black to 24.4.2. `#185 <https://github.com/dajiaji/pyseto/pull/185>`__
    - Bump blacken-docs to 1.18.0. `#185 <https://github.com/dajiaji/pyseto/pull/185>`__
    - Bump pre-commit/flake8 to 7.1.0. `#185 <https://github.com/dajiaji/pyseto/pull/185>`__
    - Bump pre-commit/pre-commit-hooks to 4.6.0. `#185 <https://github.com/dajiaji/pyseto/pull/185>`__
    - Bump pytest-cov to 5.0.0. `#184 <https://github.com/dajiaji/pyseto/pull/184>`__

Version 0.5.3
-------------

Released 2024-01-27

- Update dependencies.
    - Bump cryptography to 42.0.1. `#163 <https://github.com/dajiaji/pyhpke/pull/163>`__
- Update dev dependencies.
    - Bump sphinx-autodoc-typehints to 1.25.3. `#164 <https://github.com/dajiaji/pyhpke/pull/164>`__
    - Bump tox to 4.12.1. `#161 <https://github.com/dajiaji/pyhpke/pull/161>`__
    - Bump flake8 to 7.0.0. `#159 <https://github.com/dajiaji/pyhpke/pull/159>`__
    - Bump pytest to 7.4.4. `#158 <https://github.com/dajiaji/pyhpke/pull/158>`__
    - Bump black to 23.12.1. `#157 <https://github.com/dajiaji/pyhpke/pull/157>`__
    - Bump pre-commit/mirrors-mypy to 1.7.1. `#157 <https://github.com/dajiaji/pyhpke/pull/157>`__
    - Bump isort to 5.13.2. `#156 <https://github.com/dajiaji/pyhpke/pull/156>`__
    - Update Sphinx version to over 7.1. `#154 <https://github.com/dajiaji/pyhpke/pull/154>`__
    - Bump sphinx-rtd-theme to 2.0.0. `#153 <https://github.com/dajiaji/pyhpke/pull/153>`__

Version 0.5.2
-------------

Released 2023-11-25

- Tighten the range of pyca/cryptography version. `#147 <https://github.com/dajiaji/pyhpke/pull/147>`__
- Add Python 3.12 to tox.ini. `#147 <https://github.com/dajiaji/pyhpke/pull/147>`__
- Fix .readthedocs.yml. `#146 <https://github.com/dajiaji/pyhpke/pull/146>`__
- Update dependencies.
    - Bump cryptography to 41.0.5. `#130 <https://github.com/dajiaji/pyhpke/pull/130>`__
- Update dev dependencies.
    - Bump actions/{checkout, setup-python} to v4. `#145 <https://github.com/dajiaji/pyhpke/pull/145>`__
    - Bump black to 23.11.0. `#144 <https://github.com/dajiaji/pyhpke/pull/144>`__
    - Bump pre-commit/mirrors-mypy to 1.7.0. `#144 <https://github.com/dajiaji/pyhpke/pull/144>`__
    - Bump sphinx-autodoc-typehints to 1.25.2. `#143 <https://github.com/dajiaji/pyhpke/pull/143>`__
    - Bump sphinx-rtd-theme to 2.0.0rc4. `#141 <https://github.com/dajiaji/pyhpke/pull/141>`__

Version 0.5.1
-------------

Released 2023-10-30

- Fix bug on EC serialization. `#137 <https://github.com/dajiaji/pyhpke/pull/137>`__
- Add example for derive_key_pair to README. `#136 <https://github.com/dajiaji/pyhpke/pull/136>`__

Version 0.5.0
-------------

Released 2023-10-27

- Add derive_key_pair to KEM interface. `#133 <https://github.com/dajiaji/pyhpke/pull/133>`__
- Update dependencies.
    - Bump cryptography to 41.0.5. `#130 <https://github.com/dajiaji/pyhpke/pull/130>`__
- Update dev dependencies.
    - Bump pytest to 7.4.3. `#132 <https://github.com/dajiaji/pyhpke/pull/132>`__
    - Bump sphinx-rtd-theme to 2.0.0rc3. `#131 <https://github.com/dajiaji/pyhpke/pull/131>`__
    - Bump black to 23.10.1. `#129 <https://github.com/dajiaji/pyhpke/pull/129>`__
    - Bump pre-commit/mirrors-mypy to 1.6.1. `#129 <https://github.com/dajiaji/pyhpke/pull/129>`__
    - Bump pre-commit to 3.5.0. `#127 <https://github.com/dajiaji/pyhpke/pull/127>`__
    - Bump blacken-docs to 1.16.0. `#123 <https://github.com/dajiaji/pyhpke/pull/123>`__
    - Bump flake8 to 6.1.0. `#123 <https://github.com/dajiaji/pyhpke/pull/123>`__
    - Bump pytest to 7.4.2. `#122 <https://github.com/dajiaji/pyhpke/pull/122>`__
    - Bump tox to 4.11.3. `#121 <https://github.com/dajiaji/pyhpke/pull/121>`__
    - Bump sphinx-autodoc-typehints to 1.24.0. `#114 <https://github.com/dajiaji/pyhpke/pull/114>`__
    - Bump sphinx to 7.1.2. `#113 <https://github.com/dajiaji/pyhpke/pull/113>`__

Version 0.4.2
-------------

Released 2023-07-03

- Add support for Python 3.11. `#97 <https://github.com/dajiaji/pyhpke/pull/97>`__
- Drop support for Python 3.7. `#95 <https://github.com/dajiaji/pyhpke/pull/95>`__
- Update dependencies.
    - Bump cryptography to 41.0.0. `#99 <https://github.com/dajiaji/pyhpke/pull/99>`__
- Update dev dependencies.
    - Bump pytest to 7.4.0. `#93 <https://github.com/dajiaji/pyhpke/pull/93>`__
    - Bump tox to 4.6.3. `#92 <https://github.com/dajiaji/pyhpke/pull/92>`__
    - Bump sphinx-rtd-theme to 1.2.2. `#90 <https://github.com/dajiaji/pyhpke/pull/90>`__
    - Bump pytest-cov to 4.1.0. `#85 <https://github.com/dajiaji/pyhpke/pull/85>`__

Version 0.4.1
-------------

Released 2023-02-18

- Add SECURITY.md. `#67 <https://github.com/dajiaji/pyhpke/pull/67>`__
- Use allowlist_externals on tox. `#37 <https://github.com/dajiaji/pyhpke/pull/37>`__
- Remove log. `#18 <https://github.com/dajiaji/pyhpke/pull/18>`__
- Update dependencies.
    - Bump cryptography to 39.0.1. `#64 <https://github.com/dajiaji/pyhpke/pull/64>`__
- Update dev dependencies.
    - Bump sphinx-rtd-theme to 1.2.0. `#66 <https://github.com/dajiaji/pyhpke/pull/66>`__
    - Bump tox to 4.4.5. `#65 <https://github.com/dajiaji/pyhpke/pull/65>`__
    - Bump black to 23.1.0. `#63 <https://github.com/dajiaji/pyhpke/pull/63>`__
    - Bump isort to 5.12.0. `#60 <https://github.com/dajiaji/pyhpke/pull/60>`__
    - Bump blacken-docs to 1.13.0. `#56 <https://github.com/dajiaji/pyhpke/pull/56>`__
    - Bump sphinx-autodoc-typehints to 1.21.0. `#55 <https://github.com/dajiaji/pyhpke/pull/55>`__
    - Bump pytest to 7.2.1. `#54 <https://github.com/dajiaji/pyhpke/pull/54>`__
    - Bump flake8 to 6.0.0. `#21 <https://github.com/dajiaji/pyhpke/pull/21>`__
    - Bump pre-commit-hooks to 4.4.0. `#21 <https://github.com/dajiaji/pyhpke/pull/21>`__

Version 0.4.0
-------------

Released 2022-11-15

- Add from_pyca_cryptography_key to KEMKey. `#16 <https://github.com/dajiaji/pyhpke/pull/16>`__
- Update dev dependencies.
    - Bump pre-commit/mirrors-mypy to 0.990. `#15 <https://github.com/dajiaji/pyhpke/pull/15>`__
    - Bump tox to 3.27.1. `#15 <https://github.com/dajiaji/pyhpke/pull/15>`__
    - Bump sphinx-rtd-theme to 1.1.1. `#13 <https://github.com/dajiaji/pyhpke/pull/13>`__

Version 0.3.0
-------------

Released 2022-11-05

- First public release.

Version 0.2.0
-------------

Released 2022-10-29

- Experimental release (3) based on https://github.com/ctz/hpke-py.

Version 0.1.1
-------------

Released 2022-10-16

- Experimental release (2) based on https://github.com/ctz/hpke-py.

Version 0.1.0
-------------

Released 2022-10-16

- Experimental release (1) based on https://github.com/ctz/hpke-py.
